@@ -1,14 +1,13 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 
 from trytond.pool import PoolMeta
 
 __all__ = ['Sale']
-__metaclass__ = PoolMeta
 
 
-class Sale:
+class Sale(metaclass=PoolMeta):
     __name__ = 'sale.sale'
 
     def _get_carrier_context(self):
@@ -22,10 +21,9 @@ class Sale:
         amount = 0
         for line in self.lines or []:
             if (getattr(line, 'unit_price', None)
-                    and getattr(line, 'quantity', None)
+                    and (getattr(line, 'quantity') or 0) > 0
                     and not getattr(line, 'shipment_cost', None)):
-                amount += (line.unit_price
-                    * Decimal(str(line.quantity or 0)))
+                amount += line.unit_price * Decimal(str(line.quantity))
         context['amount'] = amount
         context['currency'] = self.currency.id
         return context
